diff -pruN 1.1.2-1/.github/workflows/cmake-multi-platform.yml 1.1.3-1/.github/workflows/cmake-multi-platform.yml
--- 1.1.2-1/.github/workflows/cmake-multi-platform.yml	1970-01-01 00:00:00.000000000 +0000
+++ 1.1.3-1/.github/workflows/cmake-multi-platform.yml	2024-03-22 06:21:05.000000000 +0000
@@ -0,0 +1,72 @@
+# This starter workflow is for a CMake project running on multiple platforms. There is a different starter workflow if you just want a single platform.
+# See: https://github.com/actions/starter-workflows/blob/main/ci/cmake-single-platform.yml
+name: CMake on multiple platforms
+
+on: [push, workflow_dispatch]
+
+jobs:
+  build:
+    runs-on: ${{ matrix.os }}
+
+    strategy:
+      # Set fail-fast to false to ensure that feedback is delivered for all matrix combinations. Consider changing this to true when your workflow is stable.
+      fail-fast: false
+
+      # Set up a matrix to run the following 3 configurations:
+      # 1. <Windows, Release, latest MSVC compiler toolchain on the default runner image, default generator>
+      # 2. <Linux, Release, latest GCC compiler toolchain on the default runner image, default generator>
+      # 3. <Linux, Release, latest Clang compiler toolchain on the default runner image, default generator>
+      #
+      # To add more build types (Release, Debug, RelWithDebInfo, etc.) customize the build_type list.
+      matrix:
+        os: [ubuntu-latest, windows-latest]
+        build_type: [Release]
+        c_compiler: [gcc, clang, cl]
+        include:
+          - os: windows-latest
+            c_compiler: cl
+            cpp_compiler: cl
+          - os: ubuntu-latest
+            c_compiler: gcc
+            cpp_compiler: g++
+          - os: ubuntu-latest
+            c_compiler: clang
+            cpp_compiler: clang++
+        exclude:
+          - os: windows-latest
+            c_compiler: gcc
+          - os: windows-latest
+            c_compiler: clang
+          - os: ubuntu-latest
+            c_compiler: cl
+
+    steps:
+    - uses: actions/checkout@v3
+
+    - name: Set reusable strings
+      # Turn repeated input strings (such as the build output directory) into step outputs. These step outputs can be used throughout the workflow file.
+      id: strings
+      shell: bash
+      run: |
+        echo "build-output-dir=${{ github.workspace }}/build" >> "$GITHUB_OUTPUT"
+
+    - name: Configure CMake
+      # Configure CMake in a 'build' subdirectory. `CMAKE_BUILD_TYPE` is only required if you are using a single-configuration generator such as make.
+      # See https://cmake.org/cmake/help/latest/variable/CMAKE_BUILD_TYPE.html?highlight=cmake_build_type
+      run: >
+        cmake -B ${{ steps.strings.outputs.build-output-dir }}
+        -DCMAKE_CXX_COMPILER=${{ matrix.cpp_compiler }}
+        -DCMAKE_C_COMPILER=${{ matrix.c_compiler }}
+        -DCMAKE_BUILD_TYPE=${{ matrix.build_type }}
+        -DCMAKE_C_FLAGS=${{ matrix.c_compiler == 'gcc' && '-Wall -Wundef -Werror' || '' }}
+        -S ${{ github.workspace }}
+
+    - name: Build
+      # Build your program with the given configuration. Note that --config is needed because the default Windows generator is a multi-config generator (Visual Studio generator).
+      run: cmake --build ${{ steps.strings.outputs.build-output-dir }} --config ${{ matrix.build_type }}
+
+    - name: Test
+      working-directory: ${{ steps.strings.outputs.build-output-dir }}
+      # Execute tests defined by the CMake configuration. Note that --build-config is needed because the default Windows generator is a multi-config generator (Visual Studio generator).
+      # See https://cmake.org/cmake/help/latest/manual/ctest.1.html for more detail
+      run: ctest --build-config ${{ matrix.build_type }}
diff -pruN 1.1.2-1/.github/workflows/cmake.yml 1.1.3-1/.github/workflows/cmake.yml
--- 1.1.2-1/.github/workflows/cmake.yml	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/.github/workflows/cmake.yml	1970-01-01 00:00:00.000000000 +0000
@@ -1,46 +0,0 @@
-name: CMake
-
-on: [push]
-
-env:
-  # Customize the CMake build type here (Release, Debug, RelWithDebInfo, etc.)
-  BUILD_TYPE: Release
-
-jobs:
-  build:
-    # The CMake configure and build commands are platform agnostic and should work equally
-    # well on Windows or Mac.  You can convert this to a matrix build if you need
-    # cross-platform coverage.
-    # See: https://docs.github.com/en/free-pro-team@latest/actions/learn-github-actions/managing-complex-workflows#using-a-build-matrix
-    runs-on: ubuntu-latest
-
-    steps:
-    - uses: actions/checkout@v2
-
-    - name: Create Build Environment
-      # Some projects don't allow in-source building, so create a separate build directory
-      # We'll use this as our working directory for all subsequent commands
-      run: cmake -E make_directory ${{github.workspace}}/build
-
-    - name: Configure CMake
-      # Use a bash shell so we can use the same syntax for environment variable
-      # access regardless of the host operating system
-      shell: bash
-      working-directory: ${{github.workspace}}/build
-      # Note the current convention is to use the -S and -B options here to specify source 
-      # and build directories, but this is only available with CMake 3.13 and higher.  
-      # The CMake binaries on the Github Actions machines are (as of this writing) 3.12
-      run: cmake $GITHUB_WORKSPACE -DCMAKE_BUILD_TYPE=$BUILD_TYPE
-
-    - name: Build
-      working-directory: ${{github.workspace}}/build
-      shell: bash
-      # Execute the build.  You can specify a specific target with "--target <NAME>"
-      run: cmake --build . --config $BUILD_TYPE
-
-    - name: Test
-      working-directory: ${{github.workspace}}/build
-      shell: bash
-      # Execute tests defined by the CMake configuration.  
-      # See https://cmake.org/cmake/help/latest/manual/ctest.1.html for more detail
-      run: ctest -C $BUILD_TYPE
diff -pruN 1.1.2-1/CHANGELOG.md 1.1.3-1/CHANGELOG.md
--- 1.1.2-1/CHANGELOG.md	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/CHANGELOG.md	2024-03-22 06:21:05.000000000 +0000
@@ -1,6 +1,12 @@
 # libaec Changelog
 All notable changes to libaec will be documented in this file.
 
+## [1.1.3] - 2024-03-21
+
+### Fixed
+- Compiler warnings
+
+
 ## [1.1.2] - 2023-10-04
 
 ### Fixed
diff -pruN 1.1.2-1/CMakeLists.txt 1.1.3-1/CMakeLists.txt
--- 1.1.2-1/CMakeLists.txt	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/CMakeLists.txt	2024-03-22 06:21:05.000000000 +0000
@@ -1,8 +1,5 @@
 cmake_minimum_required(VERSION 3.13...3.19)
-project(libaec LANGUAGES C VERSION 1.1.2)
-
-# Automatically export symbols for Windows DLLs
-set(CMAKE_WINDOWS_EXPORT_ALL_SYMBOLS TRUE)
+project(libaec LANGUAGES C VERSION 1.1.3)
 
 set(CMAKE_C_STANDARD 99)
 set(CMAKE_C_VISIBILITY_PRESET hidden)
diff -pruN 1.1.2-1/LICENSE.txt 1.1.3-1/LICENSE.txt
--- 1.1.2-1/LICENSE.txt	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/LICENSE.txt	2024-03-22 06:21:05.000000000 +0000
@@ -1,4 +1,4 @@
-Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
diff -pruN 1.1.2-1/cmake/config.h.in 1.1.3-1/cmake/config.h.in
--- 1.1.2-1/cmake/config.h.in	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/cmake/config.h.in	2024-03-22 06:21:05.000000000 +0000
@@ -1,6 +1,6 @@
 #cmakedefine WORDS_BIGENDIAN
 #cmakedefine01 HAVE_DECL___BUILTIN_CLZLL
-#cmakedefine01 HAVE_BSR64
+#cmakedefine HAVE_BSR64
 #cmakedefine HAVE_SNPRINTF
 #cmakedefine HAVE__SNPRINTF
 #cmakedefine HAVE__SNPRINTF_S
diff -pruN 1.1.2-1/cmake/libaec-config.cmake.in 1.1.3-1/cmake/libaec-config.cmake.in
--- 1.1.2-1/cmake/libaec-config.cmake.in	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/cmake/libaec-config.cmake.in	2024-03-22 06:21:05.000000000 +0000
@@ -59,6 +59,12 @@ if (libaec_FOUND)
     add_library(libaec::aec STATIC IMPORTED)
   else ()
     add_library(libaec::aec SHARED IMPORTED)
+    target_compile_definitions(libaec::aec INTERFACE LIBAEC_SHARED)
+    if (MSVC)
+      set_target_properties(libaec::aec PROPERTIES
+        IMPORTED_IMPLIB "${libaec_LIBRARY}"
+      )
+    endif ()
   endif ()
   set_target_properties(libaec::aec PROPERTIES
     IMPORTED_LOCATION "${libaec_LIBRARY}"
@@ -70,6 +76,12 @@ if (libaec_FOUND)
     add_library(libaec::sz STATIC IMPORTED)
   else ()
     add_library(libaec::sz SHARED IMPORTED)
+    target_compile_definitions(libaec::sz INTERFACE LIBAEC_SHARED)
+    if (MSVC)
+      set_target_properties(libaec::sz PROPERTIES
+        IMPORTED_IMPLIB "${SZIP_LIBRARY}"
+      )
+    endif ()
   endif ()
   set_target_properties(libaec::sz PROPERTIES
     IMPORTED_LOCATION "${SZIP_LIBRARY}"
diff -pruN 1.1.2-1/configure.ac 1.1.3-1/configure.ac
--- 1.1.2-1/configure.ac	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/configure.ac	2024-03-22 06:21:05.000000000 +0000
@@ -2,7 +2,7 @@ AC_PREREQ([2.71])
 
 m4_define([VERSION_MAJOR], [1])
 m4_define([VERSION_MINOR], [1])
-m4_define([VERSION_PATCH], [2])
+m4_define([VERSION_PATCH], [3])
 
 AC_INIT([libaec],[VERSION_MAJOR.VERSION_MINOR.VERSION_PATCH],[rosenhauer@dkrz.de])
 
diff -pruN 1.1.2-1/debian/changelog 1.1.3-1/debian/changelog
--- 1.1.2-1/debian/changelog	2023-10-06 08:18:51.000000000 +0000
+++ 1.1.3-1/debian/changelog	2024-03-22 08:50:51.000000000 +0000
@@ -1,3 +1,9 @@
+libaec (1.1.3-1) unstable; urgency=medium
+
+  * New upstream release
+
+ -- Alastair McKinstry <mckinstry@debian.org>  Fri, 22 Mar 2024 08:50:51 +0000
+
 libaec (1.1.2-1) unstable; urgency=medium
 
   * New upstream release
diff -pruN 1.1.2-1/include/libaec.h.in 1.1.3-1/include/libaec.h.in
--- 1.1.2-1/include/libaec.h.in	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/include/libaec.h.in	2024-03-22 06:21:05.000000000 +0000
@@ -2,7 +2,7 @@
  * @file libaec.h
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -49,8 +49,14 @@
 extern "C"{
 #endif
 
-#if BUILDING_LIBAEC && HAVE_VISIBILITY
+#if defined LIBAEC_BUILD && HAVE_VISIBILITY
 #  define LIBAEC_DLL_EXPORTED __attribute__((__visibility__("default")))
+#elif (defined _WIN32 && !defined __CYGWIN__) && defined LIBAEC_SHARED
+#  if defined LIBAEC_BUILD
+#    define LIBAEC_DLL_EXPORTED __declspec(dllexport)
+#  else
+#    define LIBAEC_DLL_EXPORTED __declspec(dllimport)
+#  endif
 #else
 #  define LIBAEC_DLL_EXPORTED
 #endif
diff -pruN 1.1.2-1/include/szlib.h 1.1.3-1/include/szlib.h
--- 1.1.2-1/include/szlib.h	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/include/szlib.h	2024-03-22 06:21:05.000000000 +0000
@@ -2,7 +2,7 @@
  * @file szlib.h
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
diff -pruN 1.1.2-1/src/CMakeLists.txt 1.1.3-1/src/CMakeLists.txt
--- 1.1.2-1/src/CMakeLists.txt	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/CMakeLists.txt	2024-03-22 06:21:05.000000000 +0000
@@ -22,7 +22,7 @@ add_library(aec_shared SHARED "$<TARGET_
 target_link_libraries(aec_shared PUBLIC aec)
 set_target_properties(aec_shared
   PROPERTIES
-  VERSION 0.1.2
+  VERSION 0.1.3
   SOVERSION 0
   OUTPUT_NAME aec
   PUBLIC_HEADER ${CMAKE_CURRENT_BINARY_DIR}/../include/libaec.h)
@@ -31,6 +31,8 @@ set_target_properties(aec_shared
 add_library(sz OBJECT sz_compat.c)
 target_link_libraries(sz PUBLIC aec)
 
+set(libaec_COMPILE_DEFINITIONS "LIBAEC_BUILD;LIBAEC_SHARED")
+
 # Create both static and shared szip library.
 add_library(sz_static STATIC "$<TARGET_OBJECTS:sz>" "$<TARGET_OBJECTS:aec>")
 set_target_properties(sz_static
@@ -51,16 +53,14 @@ set_target_properties(sz_shared
 add_executable(graec graec.c)
 target_link_libraries(graec aec)
 
+# Handle visibility of symbols. Compatible with gnulib's gl_VISIBILITY
+include(CheckCCompilerFlag)
+check_c_compiler_flag(-fvisibility=hidden COMPILER_HAS_HIDDEN_VISIBILITY)
+set(libaec_COMPILE_DEFINITIONS
+  "${libaec_COMPILE_DEFINITIONS};HAVE_VISIBILITY=$<BOOL:${COMPILER_HAS_HIDDEN_VISIBILITY}>")
+
 include(GNUInstallDirs)
 if(UNIX)
-  # Handle visibility of symbols. Compatible with gnulib's gl_VISIBILITY
-  include(CheckCCompilerFlag)
-  check_c_compiler_flag(-fvisibility=hidden COMPILER_HAS_HIDDEN_VISIBILITY)
-  set_target_properties(aec sz
-    PROPERTIES
-    COMPILE_DEFINITIONS
-    "HAVE_VISIBILITY=$<BOOL:${COMPILER_HAS_HIDDEN_VISIBILITY}>;BUILDING_LIBAEC")
-
   # The shell scripts for benchmarking are supported on unix only
   add_executable(utime EXCLUDE_FROM_ALL utime.c)
   target_include_directories(utime PRIVATE "${CMAKE_CURRENT_BINARY_DIR}/..")
@@ -83,4 +83,8 @@ if(UNIX OR MINGW)
 >>>>>>> upstream/1.1.1
 endif()
 
+set_target_properties(aec sz
+  PROPERTIES
+  COMPILE_DEFINITIONS "${libaec_COMPILE_DEFINITIONS}")
+
 install(TARGETS aec_static aec_shared sz_static sz_shared)
diff -pruN 1.1.2-1/src/Makefile.am 1.1.3-1/src/Makefile.am
--- 1.1.2-1/src/Makefile.am	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/Makefile.am	2024-03-22 06:21:05.000000000 +0000
@@ -1,14 +1,15 @@
 AUTOMAKE_OPTIONS = no-installman
 AM_CFLAGS = $(CFLAG_VISIBILITY)
-AM_CPPFLAGS = -I$(top_srcdir)/include -I$(top_builddir)/include \
--DBUILDING_LIBAEC
+AM_CPPFLAGS = -I$(top_srcdir)/include -I$(top_builddir)/include
 lib_LTLIBRARIES = libaec.la libsz.la
 libaec_la_SOURCES = encode.c encode_accessors.c decode.c vector.c\
 encode.h encode_accessors.h decode.h vector.h
-libaec_la_LDFLAGS = -version-info 1:2:1 -no-undefined
+libaec_la_CPPFLAGS = $(AM_CPPFLAGS) -DLIBAEC_BUILD
+libaec_la_LDFLAGS = -version-info 1:3:1 -no-undefined
 
 libsz_la_SOURCES = sz_compat.c
 libsz_la_LIBADD = libaec.la
+libsz_la_CPPFLAGS = $(AM_CPPFLAGS) -DLIBAEC_BUILD
 libsz_la_LDFLAGS = -version-info 2:1:0 -no-undefined
 
 include_HEADERS = $(top_builddir)/include/libaec.h $(top_srcdir)/include/szlib.h
diff -pruN 1.1.2-1/src/decode.c 1.1.3-1/src/decode.c
--- 1.1.2-1/src/decode.c	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/decode.c	2024-03-22 06:21:05.000000000 +0000
@@ -2,7 +2,7 @@
  * @file decode.c
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,7 +43,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#if HAVE_BSR64
+#ifdef HAVE_BSR64
 #include <intrin.h>
 #endif
 
@@ -295,7 +295,7 @@ static inline uint32_t direct_get_fs(str
 #endif
 #if HAVE_DECL___BUILTIN_CLZLL || __has_builtin(__builtin_clzll)
         int i = 63 - __builtin_clzll(state->acc);
-#elif HAVE_BSR64
+#elif defined HAVE_BSR64
         unsigned long i;
         _BitScanReverse64(&i, state->acc);
 #else
diff -pruN 1.1.2-1/src/decode.h 1.1.3-1/src/decode.h
--- 1.1.2-1/src/decode.h	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/decode.h	2024-03-22 06:21:05.000000000 +0000
@@ -2,7 +2,7 @@
  * @file decode.h
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
diff -pruN 1.1.2-1/src/encode.c 1.1.3-1/src/encode.c
--- 1.1.2-1/src/encode.c	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/encode.c	2024-03-22 06:21:05.000000000 +0000
@@ -2,7 +2,7 @@
  * @file encode.c
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -337,7 +337,7 @@ static uint32_t assess_splitting_option(
     struct internal_state *state = strm->state;
 
     /* Block size of current block */
-    int this_bs = strm->block_size - state->ref;
+    uint64_t this_bs = strm->block_size - state->ref;
 
     /* CDS length minimum so far */
     uint64_t len_min = UINT64_MAX;
@@ -890,7 +890,6 @@ int aec_encode_init(struct aec_stream *s
     *state->cds = 0;
     state->bits = 8;
     state->mode = m_get_block;
-    struct vector_t *offsets = NULL;
     state->ready_to_capture_rsi = 0;
     return AEC_OK;
 }
diff -pruN 1.1.2-1/src/encode.h 1.1.3-1/src/encode.h
--- 1.1.2-1/src/encode.h	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/encode.h	2024-03-22 06:21:05.000000000 +0000
@@ -2,7 +2,7 @@
  * @file encode.h
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
diff -pruN 1.1.2-1/src/encode_accessors.c 1.1.3-1/src/encode_accessors.c
--- 1.1.2-1/src/encode_accessors.c	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/encode_accessors.c	2024-03-22 06:21:05.000000000 +0000
@@ -2,7 +2,7 @@
  * @file encode_accessors.c
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
diff -pruN 1.1.2-1/src/encode_accessors.h 1.1.3-1/src/encode_accessors.h
--- 1.1.2-1/src/encode_accessors.h	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/encode_accessors.h	2024-03-22 06:21:05.000000000 +0000
@@ -2,7 +2,7 @@
  * @file encode_accessors.h
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
diff -pruN 1.1.2-1/src/graec.c 1.1.3-1/src/graec.c
--- 1.1.2-1/src/graec.c	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/graec.c	2024-03-22 06:21:05.000000000 +0000
@@ -2,7 +2,7 @@
  * @file aec.c
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
diff -pruN 1.1.2-1/src/sz_compat.c 1.1.3-1/src/sz_compat.c
--- 1.1.2-1/src/sz_compat.c	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/sz_compat.c	2024-03-22 06:21:05.000000000 +0000
@@ -2,7 +2,7 @@
  * @file sz_compat.c
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -71,7 +71,7 @@ static int bits_to_bytes(int bit_length)
 }
 
 static void interleave_buffer(void *dest, const void *src,
-                              size_t n, int wordsize)
+                              size_t n, size_t wordsize)
 {
     const unsigned char *src8 = (unsigned char *)src;
     unsigned char *dest8 = (unsigned char *)dest;
@@ -82,7 +82,7 @@ static void interleave_buffer(void *dest
 }
 
 static void deinterleave_buffer(void *dest, const void *src,
-                                size_t n, int wordsize)
+                                size_t n, size_t wordsize)
 {
     const unsigned char *src8 = (unsigned char *)src;
     unsigned char *dest8 = (unsigned char *)dest;
diff -pruN 1.1.2-1/src/utime.c 1.1.3-1/src/utime.c
--- 1.1.2-1/src/utime.c	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/utime.c	2024-03-22 06:21:05.000000000 +0000
@@ -4,7 +4,7 @@
  * @author Thomas Jahns, Deutsches Klimarechenzentrum
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2024 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
diff -pruN 1.1.2-1/src/vector.h 1.1.3-1/src/vector.h
--- 1.1.2-1/src/vector.h	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/src/vector.h	2024-03-22 06:21:05.000000000 +0000
@@ -1,6 +1,6 @@
 #pragma once
 
-#include <libaec.h>
+#include "config.h"
 #include <stdlib.h>
 
 struct vector_t {
diff -pruN 1.1.2-1/tests/check_rsi_block_access.c 1.1.3-1/tests/check_rsi_block_access.c
--- 1.1.2-1/tests/check_rsi_block_access.c	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/tests/check_rsi_block_access.c	2024-03-22 06:21:05.000000000 +0000
@@ -112,22 +112,6 @@ static void data_generator_incr(struct a
     }
 }
 
-static void ctx_init(struct aec_context *ctx)
-{
-    ctx->nvalues = 0;
-    ctx->flags = 0;
-    ctx->rsi = 0;
-    ctx->block_size = 0;
-    ctx->bits_per_sample = 0;
-    ctx->obuf = NULL;
-    ctx->ebuf = NULL;
-    ctx->dbuf = NULL;
-    ctx->obuf_len = 0;
-    ctx->ebuf_len = 0;
-    ctx->dbuf_len = 0;
-    ctx->ebuf_total = 0;
-}
-
 #define PREPARE_ENCODE(strm_e, ctx, flags) \
 { \
     (strm_e)->flags = flags; \
@@ -239,7 +223,6 @@ static int test_rsi_at(struct aec_contex
 {
     int status = AEC_OK;
     int flags = ctx->flags;
-    unsigned short *obuf = (unsigned short*) ctx->obuf;
 
     struct aec_stream strm_encode;
     PREPARE_ENCODE(&strm_encode, ctx, flags);
@@ -256,7 +239,7 @@ static int test_rsi_at(struct aec_contex
         exit(1);
     }
 
-    for (int i = 0; i < offsets_count; ++i) {
+    for (size_t i = 0; i < offsets_count; ++i) {
         struct aec_stream strm_at;
         strm_at.flags = flags;
         strm_at.rsi = ctx->rsi;
@@ -270,8 +253,8 @@ static int test_rsi_at(struct aec_contex
         if ((status = aec_rsi_at(&strm_at, offsets, offsets_count, i)) != AEC_OK) {
             return status;
         }
-        for (int j = 0; j < strm_at.total_out; j++) {
-            if (j == ctx->rsi * ctx->block_size * ctx->bytes_per_sample + j > ctx->obuf_len) {
+        for (size_t j = 0; j < strm_at.total_out; j++) {
+            if (j == (ctx->rsi * ctx->block_size * ctx->bytes_per_sample + j > ctx->obuf_len)) {
                 break;
             }
             if (rsi_buf[j] != ctx->obuf[i * ctx->block_size * ctx->rsi * ctx->bytes_per_sample + j]) {
@@ -297,11 +280,6 @@ int test_read(struct aec_context *ctx)
     size_t *offsets = NULL;
     size_t offsets_size = 0;
     PREPARE_DECODE_WITH_OFFSETS(&strm_decode, ctx, flags, offsets, &offsets_size);
-
-    size_t rsi_len = ctx->rsi * ctx->block_size * ctx->bytes_per_sample;
-    unsigned rsi_n = ctx->obuf_len / (ctx->rsi * ctx->block_size); // Number of full rsi blocks
-    unsigned rsi_r = ctx->obuf_len % (ctx->rsi * ctx->block_size); // Remainder
-
     // Edge case: Imposible to get wanted number of slices
     size_t wanted_num_slices = 3;
     if (wanted_num_slices > ctx->obuf_len) {
@@ -340,7 +318,6 @@ int test_read(struct aec_context *ctx)
 
     if ((status = aec_decode_init(&strm_read)) != AEC_OK)
         return status;
-    struct internal_state *state = strm_read.state;
 
     // Test 1: Stream data
     for (size_t i = 0; i < num_slices; ++i) {
@@ -360,7 +337,6 @@ int test_read(struct aec_context *ctx)
 
     // Test 2: Read slices
     for (size_t i = 0; i < num_slices; ++i) {
-        struct internal_state *state = strm_read.state;
         size_t buf_size = slice_sizes[i];;
         unsigned char *buf = malloc(buf_size);
         if (buf == NULL) {
@@ -413,8 +389,6 @@ int test_offsets(struct aec_context *ctx
         return 102;
     }
 
-    size_t size = decode_offsets_size > 10 ? 10 : decode_offsets_size;
-
     for (size_t i = 0; i < encode_offsets_size; ++i) {
         if (encode_offsets_ptr[i] != decode_offsets_ptr[i]) {
             fprintf(stderr, "Error: encode_offsets_ptr[%zu] = %zu, decode_offsets_ptr[%zu] = %zu\n", i, encode_offsets_ptr[i], i, decode_offsets_ptr[i]);
diff -pruN 1.1.2-1/tests/check_seeking.c 1.1.3-1/tests/check_seeking.c
--- 1.1.2-1/tests/check_seeking.c	2023-10-06 08:24:52.000000000 +0000
+++ 1.1.3-1/tests/check_seeking.c	2024-03-22 06:21:05.000000000 +0000
@@ -14,7 +14,7 @@ void shift_cdata(struct test_state *stat
     unsigned char *dst = state->cbuf + byte_offset;
 
     memset(state->cbuf, 0, state->buf_len);
-    for (int i = 0; i < strm->avail_in; i++) {
+    for (size_t i = 0; i < strm->avail_in; i++) {
         dst[i] |= cbuf_unshifted[i] >> bit_offset;
         dst[i + 1] |= cbuf_unshifted[i] << (8 - bit_offset);
     }
